@@ -89,35 +89,52 @@ general_garch_fitting <- function(rt, model_type, orders = c(1, 1),
     presample = presample
   )
 
+  mean_req_1 <- (!lm_arma && (meanspec@orders[[1]] > 0 || meanspec@orders[[2]]))
+  mean_req_2 <- lm_arma
+  mean_res <- if (mean_req_1) {   # run an initial ARMA to get better pre-sample values for the volatility step
+    init_arma <- suppressWarnings(stats::arima(rt_core, order = c(meanspec@orders[[1]], 0, meanspec@orders[[2]]), include.mean = meanspec@include_mean, method = "ML"))
+    init_arma$residuals
+  } else if (mean_req_2) {
+    init_farima <- tryCatch({
+      suppressWarnings(prelim_farima(x = rt_core, p = meanspec@orders[[1]], q = meanspec@orders[[2]], include_mean = meanspec@include_mean, presample = presample, trunc = trunc, Drange = Drange))
+    },
+    error = {
+      suppressWarnings(stats::arima(rt_core, order = c(meanspec@orders[[1]], 0, meanspec@orders[[2]]), include.mean = meanspec@include_mean, method = "ML"))
+    })
+    init_farima$residuals
+  } else {
+    rt_core
+  }
+
   extra_args <- switch(
     model_type,
-    "garch" = list(sig2_init = 1),
+    "garch" = list(sig2_init = stats::var(mean_res)),
     "gjrgarch" = {
       delta0 <- 2    # use delta0 = 2
       gamma0 <- 0  # use gamma0 = 0   as suitable initial guesses
-      sigd_init <- stats::sd(rt_core)^delta0
-      rt_dm <- rt_core - mean(rt_core)
-      etransf_init <- mean(abs(rt_dm) - gamma0 * rt_dm)^delta0
+      sigd_init <- stats::sd(mean_res)^delta0
+      rt_dm <-  mean_res - mean(mean_res)
+      etransf_init <- mean((abs(rt_dm ) - gamma0 *  rt_dm)^delta0)
       list(sigd_init = sigd_init, etransf_init = etransf_init)
     },
     "tgarch" = {
       delta0 <- 1    # use delta0 = 1
       gamma0 <- 0  # use gamma0 = 0   as suitable initial guesses
-      sigd_init <- stats::sd(rt_core)^delta0
-      rt_dm <- rt_core - mean(rt_core)
-      etransf_init <- mean(abs(rt_dm) - gamma0 * rt_dm)^delta0
+      sigd_init <- stats::sd(mean_res)^delta0
+      rt_dm <- mean_res - mean(mean_res)
+      etransf_init <- mean((abs(rt_dm) - gamma0 * rt_dm)^delta0)
       list(sigd_init = sigd_init, etransf_init = etransf_init)
     },
     "aparch" = {
       delta0 <- 2    # use delta0 = 2
       gamma0 <- 0  # use gamma0 = 0   as suitable initial guesses
-      sigd_init <- stats::sd(rt_core)^delta0
-      rt_dm <- rt_core - mean(rt_core)
-      etransf_init <- mean(abs(rt_dm) - gamma0 * rt_dm)^delta0
+      sigd_init <- stats::sd(mean_res)^delta0
+      rt_dm <- mean_res - mean(mean_res)
+      etransf_init <- mean((abs(rt_dm) - gamma0 * rt_dm)^delta0)
       list(sigd_init = sigd_init, etransf_init = etransf_init)
     },
     "figarch" = {
-      list(presample_val = var(rt_core))
+      list(presample_val = var(mean_res))
     },
     "figjrgarch" = {
       est_s <- suppressWarnings(gjrgarch(
@@ -134,8 +151,8 @@ general_garch_fitting <- function(rt, model_type, orders = c(1, 1),
       ))
       delta0 <- 2
       gamma0 <- est_s@pars[["gamma1"]]
-      rt_dm <- rt_core - mean(rt_core)
-      list(presample_val = mean(abs(rt_dm) - gamma0 * rt_dm)^delta0)
+      rt_dm <- mean_res - mean(mean_res)
+      list(presample_val = mean((abs(rt_dm) - gamma0 * rt_dm)^delta0))
     },
     "fitgarch" = {
       est_s <- suppressWarnings(tgarch(
@@ -152,8 +169,8 @@ general_garch_fitting <- function(rt, model_type, orders = c(1, 1),
       ))
       delta0 <- 1
       gamma0 <- est_s@pars[["gamma1"]]
-      rt_dm <- rt_core - mean(rt_core)
-      list(presample_val = mean(abs(rt_dm) - gamma0 * rt_dm)^delta0)
+      rt_dm <- mean_res - mean(mean_res)
+      list(presample_val = mean((abs(rt_dm) - gamma0 * rt_dm)^delta0))
     },
     "fiaparch" = {
       est_s <- suppressWarnings(aparch(
@@ -170,8 +187,8 @@ general_garch_fitting <- function(rt, model_type, orders = c(1, 1),
       ))
       delta0 <- est_s@pars[["delta"]]
       gamma0 <- est_s@pars[["gamma1"]]
-      rt_dm <- rt_core - mean(rt_core)
-      list(presample_val = mean(abs(rt_dm) - gamma0 * rt_dm)^delta0)
+      rt_dm <- mean_res - mean(mean_res)
+      list(presample_val = mean((abs(rt_dm) - gamma0 * rt_dm)^delta0))
     }
   )
 
@@ -196,7 +213,7 @@ general_garch_fitting <- function(rt, model_type, orders = c(1, 1),
   # using internally saved table function
   pars_and_restr <- start_pars_and_restr[[model_type]](drange, p, q)
   list2env(pars_and_restr, envir = environment())
-  rm(pars_and_restr)
+  suppressWarnings(rm("pars_and_restr", envir = environment()))
 
 
   if (is.null(start_pars) || is.null(LB) || is.null(UB)) {
