@@ -90,16 +90,14 @@ test_that("fEGarch rolling forecast works as intended without refitting", {
         utils::tail(zoo::coredata(fcast@sigt), 5)
       )
     }, {
-      c(-0.0012603512, -0.0012603512, -0.0012603512,
-        -0.0012603512, -0.0012603512, -0.0012603512,
-        -0.0012603512, -0.0012603512, -0.0012603512,
-        -0.0012603512, -0.0012603512, -0.0012603512,
-        -0.0012603512, -0.0012603512, -0.0012603512,
-        0.0097863034, 0.0090630439, 0.0094991403,
-        0.0099682965, 0.0101150485, 0.0143607021,
-        0.0134091387, 0.0120268185, 0.015408134,
-        0.0166667716, 0.0135127123, 0.0129465634,
-        0.01271435, 0.014672088, 0.0151035367)
+      c(-0.0013297617, -0.0013297617, -0.0013297617, -0.0013297617,
+        -0.0013297617, -0.0013297617, -0.0013297617, -0.0013297617,
+        -0.0013297617, -0.0013297617, -0.0013297617, -0.0013297617,
+        -0.0013297617, -0.0013297617, -0.0013297617, 0.0098636645,
+        0.0091370755, 0.0095652836, 0.0100355392, 0.0101804865,
+        0.0144549882, 0.0134981168, 0.0121056907, 0.0154557377,
+        0.0167515453, 0.0135856522, 0.013004756, 0.0127661276,
+        0.0147145849, 0.0151721568)
     }, tolerance = 1e-02)
 
     # Parametric models without mean
@@ -178,11 +176,11 @@ test_that("fEGarch rolling forecast works as intended without refitting", {
         utils::tail(zoo::coredata(fcast@sigt), 5)
       )
     }, {
-      c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-        0.0097281939, 0.0089440248, 0.0096375659, 0.010420761,
-        0.0108033544, 0.0151202502, 0.0142882662, 0.0127403048,
-        0.0159291206, 0.0167495578, 0.0138008048, 0.0134003306,
-        0.0134396787, 0.0155426014, 0.015631948)
+      c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0097997174,
+        0.0090129935, 0.0097086491, 0.0104981087, 0.0108847844,
+        0.0152125168, 0.0143810445, 0.0128270873, 0.0160088501,
+        0.0168328079, 0.0138792258, 0.0134769095, 0.0135196098,
+        0.0156250389, 0.0157158022)
     }, tolerance = 1e-02)
 
 
@@ -237,9 +235,9 @@ test_that("fEGarch rolling forecast works as intended without refitting", {
       )
     }, {
       c(rep(mean(utils::head(rt, -250)), 15),
-        0.0073930335, 0.0067632251, 0.0073322214, 0.0083405667, 0.0088772311,
-        0.0130886201, 0.0126423295, 0.0112292598, 0.0126671852, 0.013546193,
-        0.011818647, 0.0114294269, 0.011811047, 0.0132955867, 0.0135067545)
+        0.0075821804, 0.0069522163, 0.0075006316, 0.0084272533, 0.0088983383,
+        0.0131040334, 0.0125928886, 0.0112168068, 0.0128480623, 0.0137948355,
+        0.0119794738, 0.0115738606, 0.0118565875, 0.01334693, 0.0136058135)
     }, tolerance = 1e-02)
 
 })
@@ -329,14 +327,14 @@ test_that("fEGarch rolling forecast works as intended with refitting", {
         utils::tail(zoo::coredata(fcast@sigt), 5)
       )
     }, {
-      c(-0.0012603512, -0.0012603512, -0.0012603512, -0.0012603512,
-        -0.0012603512, -0.0014161309, -0.0014161309, -0.0014161309,
-        -0.0014161309, -0.0014161309, -0.0013408128, -0.0013408128,
-        -0.0013408128, -0.0013408128, -0.0013408128, 0.0097863034,
-        0.0090630439, 0.0094991403, 0.0099682965, 0.0101150485,
-        0.0139026504, 0.0130335987, 0.0117988111, 0.0148467807,
-        0.0164970277, 0.0136725943, 0.0137261681, 0.01332404,
-        0.0150394628, 0.0140054597)
+      c(-0.0013297617, -0.0013297617, -0.0013297617, -0.0013297617,
+        -0.0013297617, -0.0014834688, -0.0014834688, -0.0014834688,
+        -0.0014834688, -0.0014834688, -0.0014323719, -0.0014323719,
+        -0.0014323719, -0.0014323719, -0.0014323719, 0.0098636645,
+        0.0091370755, 0.0095652836, 0.0100355392, 0.0101804865,
+        0.0140092149, 0.0131341032, 0.0118867891, 0.014908144,
+        0.0165840706, 0.0139971956, 0.0141038452, 0.0137539665,
+        0.0154421358, 0.0143937793)
     }, tolerance = 1e-02)
 
     # Parametric models without mean
@@ -410,10 +408,10 @@ test_that("fEGarch rolling forecast works as intended with refitting", {
         utils::tail(zoo::coredata(fcast@sigt), 5)
       )
     }, {
-      c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0097281939, 0.0089440248,
-        0.0096375659, 0.010420761, 0.0108033544, 0.0147235622, 0.0139823541,
-        0.0126027358, 0.0153525611, 0.0165106421, 0.0138494556, 0.0140249392,
-        0.0137830685, 0.0154744842, 0.0143274471)
+      c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0097997174, 0.0090129935,
+        0.0097086491, 0.0104981087, 0.0108847844, 0.0148155045, 0.0140744621,
+        0.0126919287, 0.0154405669, 0.0165885406, 0.0139946443, 0.0141798827,
+        0.0139590044, 0.015648592, 0.0144981964)
     }, tolerance = 1e-02)
 
 
@@ -470,12 +468,14 @@ test_that("fEGarch rolling forecast works as intended with refitting", {
         utils::tail(zoo::coredata(fcast@sigt), 5)
       )
     }, {
-      c(-0.0004435214, -0.0004435214, -0.0004435214, -0.0004435214, -0.0004435214,
-        -0.0005152874, -0.0005152874, -0.0005152874, -0.0005152874, -0.0005152874,
-        -0.0007104339, -0.0007104339, -0.0007104339, -0.0007104339, -0.0007104339,
-        0.0073929834, 0.0067631773, 0.0073321801, 0.0083405422, 0.0088772214,
-        0.0260863117, 0.0252633269, 0.0236010593, 0.0251350347, 0.0260385369,
-        0.0290104597, 0.0285208587, 0.028766602, 0.0302529273, 0.0306257318)
+      c(-0.0004435214, -0.0004435214, -0.0004435214, -0.0004435214,
+        -0.0004435214, -0.0005152874, -0.0005152874, -0.0005152874,
+        -0.0005152874, -0.0005152874, -0.0007104339, -0.0007104339,
+        -0.0007104339, -0.0007104339, -0.0007104339, 0.0075814763,
+        0.0069514763, 0.0074999657, 0.0084269418, 0.0088982943,
+        0.0259810298, 0.0251452974, 0.023573328, 0.0251463375,
+        0.0260728211, 0.0291053548, 0.0286310211, 0.0287929142,
+        0.0301934132, 0.0305810297)
     }, tolerance = 1e-02)
 
 })
